@@ -1,11 +1,11 @@
-# Copyrights 2001-2009 by Mark Overmeer.
+# Copyrights 2001-2014 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 1.06.
+# Pod stripped from pm file by OODoc 2.01.
 
 package Mail::Box::File;
 use vars '$VERSION';
-$VERSION = '2.093';
+$VERSION = '2.110';
 
 use base 'Mail::Box';
 
@@ -45,18 +45,19 @@ sub init($)
     $args->{body_type} ||= \&_default_body_type;
     $args->{lock_file} ||= '--';   # to be resolved later
 
-    return unless defined $self->SUPER::init($args);
+    defined $self->SUPER::init($args)
+        or return;
 
     my $class    = ref $self;
 
     my $filename = $self->{MBF_filename}
-       = $class->folderToFilename
+       = $self->folderToFilename
            ( $self->name
            , $self->folderdir
            );
 
        if(-e $filename) {;}    # Folder already exists
-    elsif(   $args->{create} && $class->create($args->{folder}, %$args)) {;}
+    elsif($args->{create} && $class->create($args->{folder}, %$args)) {;}
     else
     {   $self->log(PROGRESS =>
                       "File $filename for folder $self does not exist.");
