@@ -1,11 +1,11 @@
-# Copyrights 2001-2011 by Mark Overmeer.
+# Copyrights 2001-2014 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.00.
+# Pod stripped from pm file by OODoc 2.01.
 
 package Mail::Box::MH::Index;
 use vars '$VERSION';
-$VERSION = '2.099';
+$VERSION = '2.110';
 
 use base 'Mail::Reporter';
 
@@ -52,7 +52,7 @@ sub write(@)
     }
 
     local *INDEX;
-    open INDEX, '>', $index
+    open INDEX, '>:raw', $index
         or return $self;
 
     my $fieldtype = 'Mail::Message::Field';
@@ -85,7 +85,7 @@ sub append(@)
     my $index     = $self->filename or return $self;
 
     local *INDEX;
-    open INDEX, '>>', $index
+    open INDEX, '>>:raw', $index
         or return $self;
 
     my $fieldtype = 'Mail::Message::Field';
