@@ -1,11 +1,11 @@
-# Copyrights 2001-2012 by Mark Overmeer.
+# Copyrights 2001-2014 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.00.
+# Pod stripped from pm file by OODoc 2.01.
 
 package Mail::Box::Mbox;
 use vars '$VERSION';
-$VERSION = '2.102';
+$VERSION = '2.110';
 
 use base 'Mail::Box::File';
 
@@ -67,7 +67,7 @@ sub foundIn($@)
     return 0 unless -f $filename;
     return 1 if -z $filename;               # empty folder is ok
 
-    open my $file, '<', $filename or return 0;
+    open my $file, '<:raw', $filename or return 0;
     local $_;
     while(<$file>)
     {   next if /^\s*$/;                    # skip empty lines
@@ -136,7 +136,7 @@ sub listSubFolders(@)
     # Some files have to be removed because they are created by all
     # kinds of programs, but are no folders.
 
-    my @entries = grep { ! m/\.lo?ck$/ && ! m/^\./ } readdir DIR;
+    my @entries = grep !m/\.lo?ck$|^\./, readdir DIR;
     closedir DIR;
 
     # Look for files in the folderdir.  They should be readable to
@@ -167,7 +167,13 @@ sub listSubFolders(@)
         }
     }
 
-    map { m/(.*)/ && $1 } keys %folders;   # untained names
+    map +(m/(.*)/ && $1), keys %folders;   # untained names
+}
+
+sub openRelatedFolder(@)
+{   my $self = shift;
+    $self->SUPER::openRelatedFolder(subfolder_extension => $self->{MBM_sub_ext}
+      , @_);
 }
 
 #-------------------------------------------
