@@ -1,13 +1,13 @@
-# Copyrights 2001-2012 by [Mark Overmeer].
+# Copyrights 2001-2014 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.00.
+# Pod stripped from pm file by OODoc 2.01.
 use strict;
 use warnings;
 
 package Mail::Message;
 use vars '$VERSION';
-$VERSION = '2.105';
+$VERSION = '2.110';
 
 use base 'Mail::Reporter';
 
@@ -21,6 +21,7 @@ use Mail::Message::Body::Nested;
 
 use Carp;
 use Scalar::Util   'weaken';
+use Devel::GlobalDestruction 'in_global_destruction';
 
 
 our $crlf_platform;
@@ -114,6 +115,13 @@ sub container() { undef } # overridden by Mail::Message::Part
 sub isPart() { 0 } # overridden by Mail::Message::Part
 
 
+sub partNumber()
+{   my $self = shift;
+    my $cont = $self->container;
+    $cont ? $cont->partNumber : undef;
+}
+
+
 sub toplevel() { shift } # overridden by Mail::Message::Part
 
 
@@ -682,7 +690,7 @@ sub shortString()
 
 sub DESTROY()
 {   my $self = shift;
-    return if $self->inGlobalDestruction;
+    return if in_global_destruction;
 
     $self->SUPER::DESTROY;
     $self->head(undef);
