@@ -1,14 +1,14 @@
-# Copyrights 2001-2012 by [Mark Overmeer].
+# Copyrights 2001-2014 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.00.
+# Pod stripped from pm file by OODoc 2.01.
 
 use strict;
 use warnings;
 
 package Mail::Message::Body;
 use vars '$VERSION';
-$VERSION = '2.105';
+$VERSION = '2.110';
 
 use base 'Mail::Reporter';
 
@@ -219,15 +219,17 @@ sub dispositionFilename(;$)
 
     my $field;
     if($field = $self->disposition)
-    {   $raw  = $field->attribute('filename')
-             || $field->attribute('file')
-             || $field->attribute('name');
+    {   $field = $field->study if $field->can('study');
+        $raw   = $field->attribute('filename')
+              || $field->attribute('file')
+              || $field->attribute('name');
     }
 
     if(!defined $raw && ($field = $self->type))
-    {   $raw  = $field->attribute('filename')
-             || $field->attribute('file')
-             || $field->attribute('name');
+    {   $field = $field->study if $field->can('study');
+        $raw   = $field->attribute('filename')
+              || $field->attribute('file')
+              || $field->attribute('name');
     }
 
     my $base;
@@ -255,7 +257,7 @@ sub dispositionFilename(;$)
         my $unique;
         for($unique = 'part-0'; 1; $unique++)
         {   my $out = File::Spec->catfile($dir, "$unique.$ext");
-            open IN, "<", $out or last;  # does not exist: can use it
+            open IN, '<', $out or last;  # does not exist: can use it
             close IN;
         }
         $filename = "$unique.$ext";
