@@ -1,13 +1,13 @@
-# Copyrights 2001-2012 by [Mark Overmeer].
+# Copyrights 2001-2014 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.00.
+# Pod stripped from pm file by OODoc 2.01.
 use strict;
 use warnings;
 
 package Mail::Message::Body::Multipart;
 use vars '$VERSION';
-$VERSION = '2.105';
+$VERSION = '2.110';
 
 use base 'Mail::Message::Body';
 
@@ -393,6 +393,23 @@ sub parts(;$)
 
 sub part($) { shift->{MMBM_parts}[shift] }
 
+sub partNumberOf($)
+{   my ($self, $part) = @_;
+    my @parts = $self->parts('ACTIVE');
+    my $msg   = $self->message;
+    unless($msg)
+    {   $self->log(ERROR => 'multipart is not connected');
+        return 'ERROR';
+    }
+    my $base  = $msg->isa('Mail::Message::Part') ? $msg->partNumber.'.' : '';
+    foreach my $partnr (0..@parts)
+    {   return $base.($partnr+1)
+            if $parts[$partnr] == $part;
+    }
+    $self->log(ERROR => 'multipart is not found or not active');
+    'ERROR';
+}
+
 
 sub boundary(;$)
 {   my $self  = shift;
