@@ -1,13 +1,13 @@
-# Copyrights 2001-2012 by [Mark Overmeer].
+# Copyrights 2001-2014 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.00.
+# Pod stripped from pm file by OODoc 2.01.
 
 use strict;
 
 package Mail::Message;
 use vars '$VERSION';
-$VERSION = '2.105';
+$VERSION = '2.110';
 
 
 use IO::Lines;
@@ -53,7 +53,7 @@ sub printStructure(;$$)
     my $fh      = @_ ? shift : select;
 
     my $buffer;   # only filled if filehandle==undef
-    open $fh, '>', \$buffer unless defined $fh;
+    open $fh, '>:raw', \$buffer unless defined $fh;
 
     my $subject = $self->get('Subject') || '';
     $subject    = ": $subject" if length $subject;
