@@ -1,17 +1,17 @@
-# Copyrights 2001-2012 by [Mark Overmeer].
+# Copyrights 2001-2014 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.00.
+# Pod stripped from pm file by OODoc 2.01.
 use warnings;
 use strict;
 
 package Mail::Message::Field::Date;
 use vars '$VERSION';
-$VERSION = '2.105';
+$VERSION = '2.110';
 
 use base 'Mail::Message::Field::Structured';
 
-use POSIX qw/mktime/;
+use POSIX qw/mktime tzset/;
 
 
 my $dayname = qr/Mon|Tue|Wed|Thu|Fri|Sat|Sun/;
@@ -30,9 +30,9 @@ sub parse($)
            ( 0?[1-9] | [12][0-9] | 3[01] ) \s* # day
            \s+ ( [A-Z][a-z][a-z] ) \s+         # month
            ( 19[0-9][0-9] | 2[0-9]{3} ) \s+    # year
-                  ( [0-1][0-9] | 2[0-3] ) \s*  # hour
-               \: ( [0-5][0-9] ) \s*           # minute
-           (?: \: ( [0-5][0-9] ) )? \s+        # second
+                  ( [0-1]?[0-9] | 2[0-3] ) \s* # hour
+               [:.] ( [0-5][0-9] ) \s*         # minute
+           (?: [:.] ( [0-5][0-9] ) )? \s+      # second
            ( [+-][0-9]{4} | [A-Z]+ )?          # zone
            \s* /x
        or return undef;
@@ -71,9 +71,15 @@ sub time()
     my ($d, $mon, $y, $h, $min, $s, $z)
       = $date =~ m/^ (?:\w\w\w\,\s+)? (\d\d)\s+(\w+)\s+(\d\d\d\d)
                      \s+ (\d\d)\:(\d\d)\:(\d\d) \s+ ([+-]\d\d\d\d)? \s*$ /x;
-    my $timestamp = mktime $s, $min, $h, $d, $monthnr{$mon}-1, $y-1900
-      , 0, 0, -1;
-    $timestamp += ($1 eq '-' ? -1 : 1) * ($2*3600 + $3*60)
+
+    my $oldtz = $ENV{TZ};
+    $ENV{TZ}  = 'UTC';
+    tzset;
+    my $timestamp = mktime $s, $min, $h, $d, $monthnr{$mon}-1, $y-1900;
+    $ENV{TZ}  = $oldtz;
+    tzset;
+
+    $timestamp += ($1 eq '-' ? 1 : -1) * ($2*3600 + $3*60)
         if $z =~ m/^([+-])(\d\d)(\d\d)$/;
     $timestamp;
 }
