@@ -1,13 +1,13 @@
-# Copyrights 2001-2012 by [Mark Overmeer].
+# Copyrights 2001-2014 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.00.
+# Pod stripped from pm file by OODoc 2.01.
 use strict;
 use warnings;
 
 package Mail::Message::Field::Full;
 use vars '$VERSION';
-$VERSION = '2.105';
+$VERSION = '2.110';
 
 use base 'Mail::Message::Field';
 
@@ -62,7 +62,7 @@ sub new($;$$@)
     }
    
     return $class->SUPER::new(%args, name => $name, body => $body)
-       if $class ne __PACKAGE__;
+        if $class ne __PACKAGE__;
 
     # Look for best class to suit this field
     my $myclass = 'Mail::Message::Field::'
@@ -75,9 +75,8 @@ sub init($)
 {   my ($self, $args) = @_;
 
     $self->SUPER::init($args);
-    $self->{MMFF_name}       = $args->{name};
-
-    my $body = $args->{body};
+    $self->{MMFF_name} = $args->{name};
+    my $body           = $args->{body};
 
        if(!defined $body || !length $body || ref $body) { ; } # no body yet
     elsif(index($body, "\n") >= 0)
@@ -120,7 +119,7 @@ sub foldedBody($)
 
     if(@_==2)
     {    $self->parse($body);
-         $body =~ s/^\s*/ /;
+         $body =~ s/^\s*/ /m;
          $self->{MMFF_body} = $body;
     }
     elsif(defined($body = $self->{MMFF_body})) { ; }
