@@ -1,18 +1,17 @@
-# Copyrights 2001-2012 by [Mark Overmeer].
+# Copyrights 2001-2014 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.00.
+# Pod stripped from pm file by OODoc 2.01.
 use strict;
 use warnings;
 
 package Mail::Message::Part;
 use vars '$VERSION';
-$VERSION = '2.105';
+$VERSION = '2.110';
 
 use base 'Mail::Message';
 
 use Scalar::Util    'weaken';
-
 use Carp;
 
 
@@ -54,19 +53,19 @@ sub coerce($@)
 
 sub buildFromBody($$;@)
 {   my ($class, $body, $container) = (shift, shift, shift);
-    my @log     = $body->logSettings;
+    my @log  = $body->logSettings;
 
-    my $head    = Mail::Message::Head::Complete->new(@log);
+    my $head = Mail::Message::Head::Complete->new(@log);
     while(@_)
     {   if(ref $_[0]) {$head->add(shift)}
         else          {$head->add(shift, shift)}
     }
 
     my $part = $class->new
-     ( head      => $head
-     , container => $container
-     , @log
-     );
+      ( head      => $head
+      , container => $container
+      , @log
+      );
 
     $part->body($body);
     $part;
@@ -88,6 +87,12 @@ sub toplevel()
 
 sub isPart() { 1 }
 
+sub partNumber()
+{   my $self = shift;
+    my $body = $self->container or confess 'no container';
+    $body->partNumberOf($self);
+}
+
 sub readFromParser($;$)
 {   my ($self, $parser, $bodytype) = @_;
 
