@@ -1,14 +1,14 @@
-# Copyrights 2001-2011 by Mark Overmeer.
+# Copyrights 2001-2014 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 2.00.
+# Pod stripped from pm file by OODoc 2.01.
 
 use strict;
 use warnings;
 
 package Mail::Server::IMAP4::Fetch;
 use vars '$VERSION';
-$VERSION = '2.099';
+$VERSION = '2.110';
 
 
 use Date::Parse;
@@ -20,12 +20,11 @@ sub new($)
 
     my $head  = $part->head;
     my $body  = $part->body;
-    
-    my $type  = $body->type;
+    my $type  = $body->type->study;
 
     my $self  = bless
       { type        => $type->body
-      , typeattr    => [ $type->attributes ]
+      , typeattr    => [ $type->attrPairs ]
       , charset     => $body->charset
       , bodylines   => $body->nrLines
       , bodysize    => $body->size
@@ -230,7 +229,7 @@ sub printStructure(;$$)
     my $number  = @_ ? shift : '';
 
     my $buffer;   # only filled if filehandle==undef
-    open $fh, '>', \$buffer unless defined $fh;
+    open $fh, '>:raw', \$buffer unless defined $fh;
 
     my $type    = $self->{type};
     my $subject = $self->{subject} || '';
